@@ -15,10 +15,12 @@ using namespace arma;
 
 #define ZERO 2e-16 // practical zero
 
-inline double sign(double x) {return((x > ZERO) ? 1 : ((x < ZERO) ? -1 : 0)) ;}
+inline double sign(double x) {return((x > ZERO) ? 1.0 : ((-x > ZERO) ? -1.0 : 0.0)) ;}
 inline vec signs(vec x) {
   vec signs = zeros<vec>(x.n_elem);
-  for (int j=0; j<x.n_elem; j++) {signs(j) = sign(x(j));}
+  for (int j=0; j<x.n_elem; j++) {
+    signs(j) = (x(j) > ZERO) ? 1.0 : ((-x(j) > ZERO) ? -1.0 : 0.0);
+  }
   return(signs);
 }
 #endif 
